summaryrefslogtreecommitdiffstats
path: root/mlir/include/mlir/AffineOps/AffineOps.h
diff options
context:
space:
mode:
Diffstat (limited to 'mlir/include/mlir/AffineOps/AffineOps.h')
-rw-r--r--mlir/include/mlir/AffineOps/AffineOps.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/mlir/include/mlir/AffineOps/AffineOps.h b/mlir/include/mlir/AffineOps/AffineOps.h
index c448b795579..b7a5c0c8326 100644
--- a/mlir/include/mlir/AffineOps/AffineOps.h
+++ b/mlir/include/mlir/AffineOps/AffineOps.h
@@ -312,12 +312,12 @@ private:
friend class AffineForOp;
};
/// The "if" operation represents an if-then-else construct for conditionally
/// executing two regions of code. The operands to an if operation are an
/// IntegerSet condition and a set of symbol/dimension operands to the
/// condition set. The operation produces no results. For example:
///
-/// if #set(%i) {
+/// affine.if #set(%i) {
/// ...
/// } else {
/// ...
@@ -326,7 +326,7 @@ private:
/// The 'else' blocks to the if operation are optional, and may be omitted. For
/// example:
///
-/// if #set(%i) {
+/// affine.if #set(%i) {
/// ...
/// }
///
@@ -337,7 +337,7 @@ public:
static void build(Builder *builder, OperationState *result,
IntegerSet condition, ArrayRef<Value *> conditionOperands);
- static StringRef getOperationName() { return "if"; }
+ static StringRef getOperationName() { return "affine.if"; }
static StringRef getConditionAttrName() { return "condition"; }
IntegerSet getIntegerSet() const;
OpenPOWER on IntegriCloud
@@ -312,12 +312,12 @@ private:
friend class AffineForOp;
};
-/// The "if" operation represents an if-then-else construct for conditionally
-/// executing two regions of code. The operands to an if operation are an
-/// IntegerSet condition and a set of symbol/dimension operands to the
+/// The "affine.if" operation represents an if-then-else construct for
+/// conditionally executing two regions of code. The operands to an if operation
+/// are an IntegerSet condition and a set of symbol/dimension operands to the
/// condition set. The operation produces no results. For example:
///